@@ -5,7 +5,7 @@ try:
 except ImportError:
     raise RuntimeError("Please use pretix 2.7 or above to run this plugin!")
 
-__version__ = "1.2.0"
+__version__ = "1.2.3"
 
 
 class PluginApp(PluginConfig):
@@ -16,7 +16,7 @@ class PluginApp(PluginConfig):
         name = gettext_lazy("Matrix inviter")
         author = "Felix Schäfer"
         description = gettext_lazy(
-            "Ask participants for their Matrix ID and invite them to a Matrix Room or Space."
+            "Invite Pretix participants to a Matrix Room or Space."
         )
         visible = True
         version = __version__
