@@ -1,10 +1,13 @@
 from django.urls import reverse
+from pretix.base.models import Event
 from pretix.control.views.event import EventSettingsFormView, EventSettingsViewMixin
 
 from .forms import MatrixInviterForm
 
 
 class MatrixInviterView(EventSettingsViewMixin, EventSettingsFormView):
+    model = Event
+    permission = "can_change_settings"
     form_class = MatrixInviterForm
     template_name = "pretix_matrix_inviter/settings.html"
 
